@@ -1,6 +1,6 @@
 ;;; no-littering.el --- help keeping ~/.emacs.d clean  -*- lexical-binding: t; -*-
 
-;; Copyright (C) 2016-2020  Jonas Bernoulli
+;; Copyright (C) 2016-2022  Jonas Bernoulli
 
 ;; Author: Jonas Bernoulli <jonas@bernoul.li>
 ;; Homepage: https://github.com/emacscollective/no-littering
@@ -36,8 +36,10 @@
 
 ;; This package sets out to fix this by changing the values of path
 ;; variables to put configuration files in `no-littering-etc-directory'
-;; (defaulting to "~/.emacs.d/etc/") and persistent data files in
-;; `no-littering-var-directory' (defaulting to "~/.emacs.d/var/"), and
+;; (defaulting to "etc/" under `user-emacs-directory', thus usually
+;; "~/.emacs.d/etc/") and persistent data files in
+;; `no-littering-var-directory' (defaulting to "var/" under
+;; `user-emacs-directory', thus usually "~/.emacs.d/var/"), and
 ;; by using descriptive file names and subdirectories when appropriate.
 ;; This is similar to a color-theme; a "path-theme" if you will.
 
@@ -51,7 +53,7 @@
 ;; location.  You will have to move the files manually.  See issue
 ;; #79 for more information.
 
-;; Usage:
+;;;; Usage
 
 ;; Load the feature `no-littering' as early as possible in your init
 ;; file.  Make sure you load it at least before you change any path
@@ -69,9 +71,10 @@
 ;;         (expand-file-name "data/" user-emacs-directory))
 ;;   (require 'no-littering)
 
-;; Conventions:
+;; For additional optional settings see "README.md".
 
-;; * A) File names
+;;;; Conventions
+;;;;; A) File names
 ;;
 ;; 1. File names are based on the name of the respective Emacs Lisp
 ;;    variables and the name of the respective Emacs package.
@@ -93,7 +96,7 @@
 ;;    E.g.  if a file contains an S-expression, then the suffix should be
 ;;    `*.el`.
 
-;; * B) File location and subdirectories
+;;;;; B) File location and subdirectories
 ;;
 ;; 1. If a package has only one data file, then that is usually placed in
 ;;    `no-littering-var-directory` itself.  Likewise if a package has
@@ -126,7 +129,7 @@
 ;;    when the name of the variable is `<package>-directory`, in which
 ;;    case we would use just `<package>/` as the path.
 
-;; * C) Ordering and alignment
+;;;;; C) Ordering and alignment
 ;;
 ;; 1. The code that sets the values of themed variables is split into two
 ;;    groups.  The first group sets the value of variables that belong to
@@ -142,7 +145,7 @@
 ;;    If it turns out that this happens very often, then we will adjust
 ;;    the alignment eventually.
 
-;; * D) Commit messages
+;;;;; D) Commit messages
 ;;
 ;; 1. Please theme each package using a separate commit and use commit
 ;;    messages of the form "<package>: theme <variable".
@@ -233,6 +236,10 @@ This variable has to be set before `no-littering' is loaded.")
     (setq eww-bookmarks-directory          (var "eww/"))
     (setq filesets-menu-cache-file         (var "filesets-menu-cache.el"))
     (setq gamegrid-user-score-file-directory (var "gamegrid-user-score/"))
+    (eval-after-load 'gnus
+      `(make-directory ,(var "gnus/dribble/") t))
+    (setq gnus-dribble-directory           (var "gnus/dribble/"))
+    (setq gnus-init-file                   (etc "gnus/init.el"))
     (setq ido-save-directory-list-file     (var "ido-save-directory-list.el"))
     (setq image-dired-db-file              (var "image-dired/db.el"))
     (setq image-dired-dir                  (var "image-dired/"))
@@ -240,6 +247,7 @@ This variable has to be set before `no-littering' is loaded.")
     (setq image-dired-temp-image-file      (var "image-dired/temp-image"))
     (setq image-dired-temp-rotate-image-file (var "image-dired/temp-rotate-image"))
     (setq kkc-init-file-name               (var "kkc-init.el"))
+    (setq multisession-directory           (var "multisession/"))
     (eval-after-load 'newsticker
       `(make-directory ,(var "newsticker/") t))
     (setq newsticker-cache-filename        (var "newsticker/cache.el"))
@@ -249,6 +257,7 @@ This variable has to be set before `no-littering' is loaded.")
       `(make-directory ,(var "org/") t))
     (setq org-clock-persist-file           (var "org/clock-persist.el"))
     (setq org-id-locations-file            (var "org/id-locations.el"))
+    (setq org-persist-directory            (var "org/persist/"))
     (setq org-publish-timestamp-directory  (var "org/timestamps/"))
     (setq project-list-file                (var "project-list.el"))
     (setq quickurl-url-file                (var "quickurl-url.el"))
@@ -260,13 +269,19 @@ This variable has to be set before `no-littering' is loaded.")
     (setq savehist-file                    (var "savehist.el"))
     (setq srecode-map-save-file            (var "srecode-map.el"))
     (setq semanticdb-default-save-directory (var "semantic/"))
+    (eval-after-load 'shadowfile
+      `(make-directory ,(var "shadow/") t))
+    (setq shadow-info-file                 (var "shadow/info.el"))
+    (setq shadow-todo-file                 (var "shadow/todo.el"))
     (setq shared-game-score-directory      (var "shared-game-score/"))
     (setq timeclock-file                   (var "timeclock"))
     (setq tramp-auto-save-directory        (var "tramp/auto-save/"))
     (setq tramp-persistency-file-name      (var "tramp/persistency.el"))
     (setq type-break-file-name             (var "type-break.el"))
     (setq url-cache-directory              (var "url/cache/"))
-    (setq url-configuration-directory      (var "url/configuration/"))
+    (setq url-configuration-directory      (var "url/"))
+    (setq url-cookie-file                  (var "url/cookies.el"))
+    (setq url-history-file                 (var "url/history.el"))
 
 ;;; Third-party packages
 
@@ -287,15 +302,24 @@ This variable has to be set before `no-littering' is loaded.")
     (setq bmkp-current-bookmark-file       (var "bmkp/current-bookmark.el"))
     (setq bmkp-last-bookmark-file          (var "bmkp/last-bookmark.el"))
     (setq bookiez-file                     (var "bookiez"))
+    (setq cider-repl-history-file          (var "cider-repl-history.el"))
+    (setq code-review-db-database-file     (var "code-review/database.sqlite"))
+    (setq code-review-download-dir         (var "code-review/downloads/"))
+    (setq code-review-log-file             (var "code-review/log"))
+    (eval-after-load 'command-log-mode
+      `(make-directory ,(var "command-log-mode-logging/") t))
+    (setq clm/logging-dir                  (var "command-log-mode/logging/"))
     (eval-after-load 'company
       `(make-directory ,(var "company/") t))
-    (setq cider-repl-history-file          (var "cider-repl-history.el"))
     (setq company-statistics-file          (var "company/statistics.el"))
     (setq company-tabnine-binaries-folder  (var "company/tabnine-binaries"))
+    (setq conventional-changelog-tmp-dir   (var "conventional-changelog/"))
     (setq dap-breakpoints-file             (var "dap/breakpoints.el"))
     (setq dap-java-test-runner             (var "lsp-java/eclipse.jdt.ls/test-runner/junit-platform-console-standalone.jar"))
     (setq dap-utils-extension-path         (var "dap/extensions/"))
     (setq debbugs-gnu-persistency-file     (var "debbugs.el"))
+    (setq devdocs-browser-cache-directory  (var "devdocs/browser-cache/"))
+    (setq devdocs-data-dir                 (var "devdocs/data/"))
     (setq dired-recent-directories-file    (var "dired-recent-directories.el"))
     (setq elbank-data-file                 (var "elbank-data.el"))
     (setq elmo-msgdb-directory             (var "elmo/"))
@@ -353,6 +377,7 @@ directories."
     (eval-after-load 'lookup
       `(make-directory ,(etc "lookup/") t))
     (setq lookup-init-directory            (etc "lookup/"))
+    (setq lsp-eslint-library-choices-file  (var "lsp/eslint-library-choices.el"))
     (setq lsp-python-ms-dir                (var "lsp-python-ms/"))
     (eval-after-load 'lsp-mode
       `(make-directory ,(var "lsp/") t))
@@ -380,6 +405,7 @@ directories."
     (setq org-journal-cache-file           (var "org/journal-cache.el"))
     (setq org-recent-headings-save-file    (var "org/recent-headings.el"))
     (setq org-registry-file                (var "org/registry.el"))
+    (setq org-roam-db-location             (var "org/org-roam.db"))
     (setq package-quickstart-file          (var "package-quickstart.el"))
     (setq pandoc-data-dir                  (etc "pandoc-mode/"))
     (setq pcache-directory                 (var "pcache/"))
@@ -399,6 +425,7 @@ directories."
     (setq quack-dir                        (var "quack/"))
     (setq rfc-mode-directory               (var "rfc-mode/"))
     (setq request-storage-directory        (var "request/storage/"))
+    (setq rime-user-data-dir               (var "rime/"))
     (setq rmh-elfeed-org-files             (list (var "elfeed/rmh-elfeed.org")))
     (setq runner-init-file                 (var "runner-init.el"))
     (setq save-kill-file-name              (var "save-kill.el"))
